//
// The Phoenix shall rise from the ashes of what fell before it.

pref("general.config.sandbox_enabled", true, locked);

pref("general.config.filename", "phoenix.cfg", locked);
pref("general.config.obscure_value", 0, locked);
pref("general.config.vendor", "phoenix", locked);

pref("browser.phoenix.applied.bootstrap", true, locked);
